

__all__ = [
    "typer_resolve_arg_flag_pair"
]



def __getattr__(name):
    if name == "typer_resolve_arg_flag_pair":
        from .cli_utils import typer_resolve_arg_flag_pair
        return typer_resolve_arg_flag_pair
    
    # other, placeholder 
    #if name == "typer_resolve_arg_flag_pair":
    #    from .cli_utils import typer_resolve_arg_flag_pair
    #    return typer_resolve_arg_flag_pair

    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")

def __dir__():
    return sorted(__all__ + [
        "__all__", "__builtins__", "__cached__", "__doc__", "__file__",
        "__getattr__", "__loader__", "__name__", "__package__", "__path__", "__spec__"
    ])




# src/memphisdrip/cli_utils.py
from __future__ import annotations

def typer_resolve_arg_flag_pair(pos: Optional[str], flag: Optional[str], default: str = None) -> str:
    """Generic resolver for any argument that can be a flag or positional."""
    try:
        import typer
    except:
        warn_missing_typer()
    val = flag or pos or default
    if val is None:
        raise typer.BadParameter("Value must be provided as an argument or flag.")
    return val

def warn_missing_typer():
    print("typer is not installed. Run: pip install 'memphisdrip[typer]'")
